from pyfrench.pyfrench import *

def test_pyfrench():
    cls()

    afficher('Salut')
    afficher(couleur(70, 45, 85, 'Salut'))

    erreur('Salut')
    attention('Salut')
    succes('Salut')

    maths("2-2*2+2/2")


from setuptools import find_packages, setup

setup(
    name='pyfrench',
    packages=find_packages(),
    version='0.1.3a',
    description='Une librairie qui traduit python en français',
    long_description='Une librairie python de toute versions qui traduit ajoute les même fonctionnalités python sur le module en français.',
    author='Artic#6377',
    author_email="artic.admisoffi@gmail.com",
    license='MIT',
    install_requires=[],
    setup_requires=['pytest-runner'],
    tests_require=['pytest==4.4.1'],
    test_suite='pyfrench',
    classifiers=[
            "License :: OSI Approved :: MIT License",
            "Programming Language :: Python :: 3",
            "Programming Language :: Python :: 3.7",
        ],
)